@@ -83,52 +83,63 @@ def chooseGeneralExperiment(self, controller, freeZebra, headEmbZebra, drosophil
     self.configFile["freeSwimmingTailTrackingMethod"] = "none"
     controller.show_frame("WellOrganisation")
 
-def wellOrganisation(self, controller, circular, rectangular, roi, other):
-  if rectangular:
-    self.shape = 'rectangular'
-    self.configFile["wellsAreRectangles"] = 1
-    controller.show_frame("CircularOrRectangularWells")
+def wellOrganisation(self, controller, circular, rectangular, roi, other, multipleROIs):
+  if multipleROIs:
+    controller.show_frame("NbRegionsOfInterest")
   else:
-    if circular and self.organism != 'drosoorrodent': # should remove the self.organism != 'drosoorrodent' at some point
-      self.shape = 'circular'
+    if rectangular:
+      self.shape = 'rectangular'
+      self.configFile["wellsAreRectangles"] = 1
       controller.show_frame("CircularOrRectangularWells")
     else:
-      self.shape = 'other'
-      if roi:
-        cap = cv2.VideoCapture(self.videoToCreateConfigFileFor)
-        cap.set(1, 10)
-        ret, frame = cap.read()
-        
-        WINDOW_NAME = "Click on the top left of the region of interest"
-        cvui.init(WINDOW_NAME)
-        cv2.moveWindow(WINDOW_NAME, 0,0)
-        cvui.imshow(WINDOW_NAME, frame)
-        while not(cvui.mouse(cvui.CLICK)):
-          cursor = cvui.mouse()
-          if cv2.waitKey(20) == 27:
-            break
-        self.configFile["oneWellManuallyChosenTopLeft"] = [cursor.x, cursor.y]
-        cv2.destroyAllWindows()
-        
-        WINDOW_NAME = "Click on the bottom right of the region of interest"
-        cvui.init(WINDOW_NAME)
-        cv2.moveWindow(WINDOW_NAME, 0,0)
-        cvui.imshow(WINDOW_NAME, frame)
-        while not(cvui.mouse(cvui.CLICK)):
-          cursor = cvui.mouse()
-          if cv2.waitKey(20) == 27:
-            break
-        self.configFile["oneWellManuallyChosenBottomRight"] = [cursor.x, cursor.y]
-        cv2.destroyAllWindows()
-        
-        self.configFile["nbWells"] = 1
-        chooseBeginningAndEndOfVideo(self, controller)
+      if circular and self.organism != 'drosoorrodent': # should remove the self.organism != 'drosoorrodent' at some point
+        self.shape = 'circular'
+        controller.show_frame("CircularOrRectangularWells")
       else:
-        self.configFile["noWellDetection"] = 1
-        self.configFile["nbWells"] = 1
-        chooseBeginningAndEndOfVideo(self, controller)
+        self.shape = 'other'
+        if roi:
+          cap = cv2.VideoCapture(self.videoToCreateConfigFileFor)
+          cap.set(1, 10)
+          ret, frame = cap.read()
+          
+          WINDOW_NAME = "Click on the top left of the region of interest"
+          cvui.init(WINDOW_NAME)
+          cv2.moveWindow(WINDOW_NAME, 0,0)
+          cvui.imshow(WINDOW_NAME, frame)
+          while not(cvui.mouse(cvui.CLICK)):
+            cursor = cvui.mouse()
+            if cv2.waitKey(20) == 27:
+              break
+          self.configFile["oneWellManuallyChosenTopLeft"] = [cursor.x, cursor.y]
+          cv2.destroyAllWindows()
+          
+          WINDOW_NAME = "Click on the bottom right of the region of interest"
+          cvui.init(WINDOW_NAME)
+          cv2.moveWindow(WINDOW_NAME, 0,0)
+          cvui.imshow(WINDOW_NAME, frame)
+          while not(cvui.mouse(cvui.CLICK)):
+            cursor = cvui.mouse()
+            if cv2.waitKey(20) == 27:
+              break
+          self.configFile["oneWellManuallyChosenBottomRight"] = [cursor.x, cursor.y]
+          cv2.destroyAllWindows()
+          
+          self.configFile["nbWells"] = 1
+          chooseBeginningAndEndOfVideo(self, controller)
+        else:
+          self.configFile["noWellDetection"] = 1
+          self.configFile["nbWells"] = 1
+          chooseBeginningAndEndOfVideo(self, controller)
 
 
+def regionsOfInterest(self, controller, nbwells):
+  
+  self.configFile["multipleROIsDefinedDuringExecution"] = 1
+  self.configFile["nbWells"] = int(nbwells)
+  
+  chooseBeginningAndEndOfVideo(self, controller)
+  
+
 def rectangularWells(self, controller, nbwells, nbRowsOfWells, nbWellsPerRows):
   
   [pathToVideo, videoName, videoExt, configFile, argv] = getMainArguments(self)
@@ -309,8 +320,10 @@ def chooseBeginningAndEndOfVideo(self, controller):
   else:
     if self.organism == 'zebrafishNew':
       controller.show_frame("NumberOfAnimals2")
-    else:
+    elif self.organism == 'zebrafish':
       controller.show_frame("NumberOfAnimals")
+    else:
+      controller.show_frame("NumberOfAnimalsCenterOfMass")
 
   
 def getImageForMultipleAnimalGUI(l, vertical, horizontal, nx, ny, max_l, videoToCreateConfigFileFor, background, wellPositions, hyperparameters):
@@ -513,7 +526,7 @@ def identifyMultipleHead(self, controller, nbanimals):
   self.configFile["headSize"]        = math.sqrt((int(hyperparameters["minArea"]) + int(hyperparameters["maxArea"])) / 2)
 
 
-def numberOfAnimals(self, controller, nbanimals, yes, noo, forceBlobMethodForHeadTracking, yesBouts, nooBouts, recommendedMethod, alternativeMethod, yesBends, nooBends):
+def numberOfAnimals(self, controller, nbanimals, yes, noo, forceBlobMethodForHeadTracking, yesBouts, nooBouts, recommendedMethod, alternativeMethod, yesBends, nooBends, adjustBackgroundExtractionBasedOnNumberOfBlackPixels):
 
   self.configFile["noBoutsDetection"] = 1
   self.configFile["noChecksForBoutSelectionInExtractParams"] = 1
@@ -546,7 +559,9 @@ def numberOfAnimals(self, controller, nbanimals, yes, noo, forceBlobMethodForHea
     method = 0
     if int(alternativeMethod):
       method = 1
-    automaticallyFindOptimalParameters(self, controller, True, detectBouts, method)
+    automaticallyFindOptimalParameters(self, controller, True, detectBouts, method, int(noo), int(adjustBackgroundExtractionBasedOnNumberOfBlackPixels))
+  elif self.organism == 'drosoorrodent' and int(recommendedMethod):
+    automaticallyFindOptimalParameters(self, controller, True, 0, 0, int(noo), int(adjustBackgroundExtractionBasedOnNumberOfBlackPixels))
   else:
     identifyMultipleHead(self, controller, nbanimals)
     controller.show_frame("FinishConfig")
